==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es_MX.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"You don't have permission to rename this document" => "No tiene permiso para cambiar de nombre a este documento",
"Saving..." => "Guardando...",
"Failed to load documents." => "Error al cargar los documentos.",
"No connection to server. Trying to reconnect." => "No hay conexión con el servidor. Intentando reconectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Si deja esta página en el modo de edición, puede que algunos datos no sean guardados. Es preferible usar el botón «Cerrar».",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "No se pudo cargar el documento. Sírvase comprobar si puede abrirlo con un editor de archivos ODT externo. También puede ser que hayan dejado de compartirlo o haya sido eliminado recientemente.",
"Save" => "Guardar",
"Loading documents..." => "Cargando los documentos...",
"'.' is an invalid file name." => "'.' no es un nombre de archivo válido.",
"File name cannot be empty." => "El nombre de archivo no puede estar vacío.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nombre inválido, los caracteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" no están permitidos ",
"Align Left" => "Alinear a la izquierda",
"Alignment" => "Alineación",
"Align Right" => "Alinear a la derecha",
"Annotate" => "Anotar",
"Background" => "Fondo",
"Bold" => "Negrita",
"Bottom" => "inferior",
"Cancel" => "Cancelar",
"Center" => "Centrado",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este estilo",
"Close" => "Cerrar",
"Color" => "Color",
"Create" => "Crear",
"Decrease Indent" => "Disminuir identación",
"Default Style" => "Estilo por defecto",
"Delete" => "Eliminar",
"Family" => "Familia",
"Font" => "Fuente",
"Font Effects" => "Efectos",
"Format" => "Formato",
"Increase Indent" => "Incrementar identación",
"Insert Image" => "Insertar una imagen",
"Invite Members" => "Invitar a miembros",
"Italic" => "Italica",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Izquierda",
"Loading" => "Cargando",
"Members" => "Miembros",
"New Name:" => "Nuevo nombre",
"OK" => "Aceptar",
"Open" => "Abrir",
"Options" => "Opciones",
"Paragraph..." => "Parrafo",
"Paragraph Styles" => "Estilo del parrafo",
"Redo" => "Rehacer",
"Right" => "Derecho",
"Size" => "Tamaño",
"Spacing" => "Espaciamiento",
"Strikethrough" => "Tachado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Superior",
"Underline" => "Subrayado",
"Undo" => "Deshacer",
"Unknown Author" => "Autor desconocido",
"Edit" => "Editar",
"Share" => "Compartir",
"Disabled" => "Deshabilitado",
"New document" => "Nuevo documento",
"Upload" => "Subir",
"Save new documents to" => "Guardar nuevos documentos en",
"Wrong password. Please retry." => "Contraseña incorrecta. Inténtelo de nuevo.",
"Password" => "Contraseña",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Este enlace caducó o nunca existió. Para más detalles, sírvase contactar a la persona que lo compartió con usted.",
"Advanced feature-set" => "Características avanzadas",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";

==> owncloud-app-documents-1%3A9.0.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/es_MX.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Documentos",
"You don't have permission to rename this document" => "No tiene permiso para cambiar de nombre a este documento",
"Saved" => "Guardado",
"Saving..." => "Guardando...",
"Failed to load documents." => "Error al cargar los documentos.",
"No connection to server. Trying to reconnect." => "No hay conexión con el servidor. Intentando reconectar.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Si deja esta página en el modo de edición, puede que algunos datos no sean guardados. Es preferible usar el botón «Cerrar».",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "No se pudo cargar el documento. Sírvase comprobar si puede abrirlo con un editor de archivos ODT externo. También puede ser que hayan dejado de compartirlo o haya sido eliminado recientemente.",
"Save" => "Guardar",
"Loading documents..." => "Cargando los documentos...",
"'.' is an invalid file name." => "'.' no es un nombre de archivo válido.",
"File name cannot be empty." => "El nombre de archivo no puede estar vacío.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Nombre inválido, los caracteres \"\\\", \"/\", \"<\", \">\", \":\", \"\", \"|\" \"?\" y \"*\" no están permitidos ",
"Align Left" => "Alinear a la izquierda",
"Alignment" => "Alineación",
"Align Right" => "Alinear a la derecha",
"Annotate" => "Anotar",
"Background" => "Fondo",
"Bold" => "Negrita",
"Bottom" => "inferior",
"Cancel" => "Cancelar",
"Center" => "Centrado",
"Clone" => "Clonar",
"Clone this Style" => "Clonar este estilo",
"Close" => "Cerrar",
"Color" => "Color",
"Create" => "Crear",
"Decrease Indent" => "Disminuir identación",
"Default Style" => "Estilo por defecto",
"Delete" => "Eliminar",
"Family" => "Familia",
"Font" => "Fuente",
"Font Effects" => "Efectos",
"Format" => "Formato",
"Increase Indent" => "Incrementar identación",
"Insert Image" => "Insertar una imagen",
"Invite Members" => "Invitar a miembros",
"Italic" => "Italica",
"Justified" => "Justificado",
"Justify" => "Justificar",
"Left" => "Izquierda",
"Loading" => "Cargando",
"Members" => "Miembros",
"New Name:" => "Nuevo nombre",
"OK" => "Aceptar",
"Open" => "Abrir",
"Options" => "Opciones",
"Paragraph..." => "Parrafo",
"Paragraph Styles" => "Estilo del parrafo",
"Redo" => "Rehacer",
"Right" => "Derecho",
"Size" => "Tamaño",
"Spacing" => "Espaciamiento",
"Strikethrough" => "Tachado",
"Style" => "Estilo",
"Text" => "Texto",
"Top" => "Superior",
"Underline" => "Subrayado",
"Undo" => "Deshacer",
"Unknown Author" => "Autor desconocido",
"Shared" => "Compartido",
"Error" => "Error",
"Error while sharing" => "Error al compartir",
"Error while unsharing" => "Error al dejar de compartir",
"Error while changing permissions" => "Error al cambiar permisos",
"Shared with you and the group {group} by {owner}" => "Compartido contigo y el grupo {group} por {owner}",
"Shared with you by {owner}" => "Compartido contigo por {owner}",
"Share" => "Compartir",
"Share link" => "Enlace compartido",
"Password protect" => "Protección con contraseña",
"Password" => "Contraseña",
"Email link to person" => "Enviar enlace por correo electrónico a una persona",
"Send" => "Enviar",
"Set expiration date" => "Establecer fecha de caducidad",
"Expiration" => "Caducidad",
"Expiration date" => "Fecha de caducidad",
"group" => "grupo",
"Resharing is not allowed" => "No se permite compartir de nuevo",
"Shared in {item} with {user}" => "Compartido en {item} con {user}",
"Unshare" => "Dejar de compartir",
"notify by email" => "notificar al usuario por correo electrónico",
"can share" => "puede compartir",
"can edit" => "puede editar",
"access control" => "control de acceso",
"create" => "crear",
"delete" => "eliminar",
"Password protected" => "Protegido con contraseña",
"Error unsetting expiration date" => "Error eliminando fecha de caducidad",
"Error setting expiration date" => "Error estableciendo fecha de caducidad",
"Sending ..." => "Enviando...",
"Email sent" => "Correo electrónico enviado",
"Warning" => "Precaución",
"Edit" => "Editar",
"Disabled" => "Deshabilitado",
"New document" => "Nuevo documento",
"Upload" => "Subir",
"Save new documents to" => "Guardar nuevos documentos en",
"Wrong password. Please retry." => "Contraseña incorrecta. Inténtelo de nuevo.",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Este enlace caducó o nunca existió. Para más detalles, sírvase contactar a la persona que lo compartió con usted.",
"Advanced feature-set" => "Características avanzadas",
"(Unstable)" => "(Inestable)"
);
$PLURAL_FORMS = "nplurals=2; plural=(n != 1);";
